==> jc-1.4.0.tar.gz: gnu/java/awt/BitwiseXORComposite__24GeneralContext.h <==
// class gnu.java.awt.BitwiseXORComposite$GeneralContext

// class file dependencies
// @dep_class d16c4b39930d90 gnu_java_awt_BitwiseXORComposite__24GeneralContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_
#define _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$_init$f7c0d85771dd4020(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$compose$eb43fc37b22d5535(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method_info$compose$eb43fc37b22d5535;
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method_info$dispose$9d5b5b52b7878138;

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods {
	void	(*compose$eb43fc37b22d5535)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *);
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *);
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*srcColorModel;
	struct _jc_java_awt_image_ColorModel$object	*dstColorModel;
	struct _jc_java_awt_Color$object	*xorColor;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs {
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object {
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite__24GeneralContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/BitwiseXORComposite__24GeneralContext.h <==
// class gnu.java.awt.BitwiseXORComposite$GeneralContext

// class file dependencies
// @dep_class d16c4b39930d90 gnu_java_awt_BitwiseXORComposite__24GeneralContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_
#define _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_Raster$object;
struct _jc_java_awt_image_WritableRaster$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$_init$f7c0d85771dd4020(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$compose$eb43fc37b22d5535(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method_info$compose$eb43fc37b22d5535;
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$method_info$dispose$9d5b5b52b7878138;

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods {
	void	(*compose$eb43fc37b22d5535)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_Raster$object *, struct _jc_java_awt_image_WritableRaster$object *) _JC_JCNI_ATTR;
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vmethods	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*srcColorModel;
	struct _jc_java_awt_image_ColorModel$object	*dstColorModel;
	struct _jc_java_awt_Color$object	*xorColor;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs {
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_refs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$sub_nonrefs	gnu_java_awt_BitwiseXORComposite__24GeneralContext;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$object {
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$vtype _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite__24GeneralContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite__24GeneralContext$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite__24GeneralContext_H_ */
